import { Server } from 'socket.io'
import { TSocket } from '../../../../utilities/types'
import path from 'path'
import fs from 'fs/promises'
import prisma from '../../../../utilities/prisma'
import CharacterManager from '../../../../managers/characterManager'
import characterRepository from '../../../../repositories/characterRepository'

/**
 * Handle game master new sprite event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:sprite:create', async (data: undefined, callback: (response: boolean) => void) => {
    try {
      const character = await characterRepository.getById(socket.characterId as number);
      if (!character) return callback(false)

      if (character.role !== 'gm') {
        return callback(false)
      }

      const public_folder = path.join(process.cwd(), 'public', 'sprites')

      // Ensure the folder exists
      await fs.mkdir(public_folder, { recursive: true })

      const sprite = await prisma.sprite.create({
        data: {
          name: 'New sprite'
        }
      })
      const uuid = sprite.id

      // Create folder with uuid
      const sprite_folder = path.join(public_folder, uuid)
      await fs.mkdir(sprite_folder, { recursive: true })

      callback(true)
    } catch (error) {
      console.error('Error creating sprite:', error)
      callback(false)
    }
  })
}
